<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
  <context>
    <name>CmdRaytracingExportProject</name>
    <message>
      <location filename="../../Command.cpp" line="522"/>
      <source>File</source>
      <translation>File</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="523"/>
      <source>&amp;Export project...</source>
      <translation>&amp;Esporta progetto...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="524"/>
      <source>Export a Raytracing project to a file</source>
      <translation>Esporta un progetto Raytracing in un file</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewLuxProject</name>
    <message>
      <location filename="../../Command.cpp" line="756"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="757"/>
      <source>New Luxrender project</source>
      <translation>Nuovo progetto Luxrender</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="758"/>
      <source>Insert new Luxrender project into the document</source>
      <translation>Inserisce un nuovo progetto Luxrender nel documento</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="810"/>
      <source>No template</source>
      <translation>Nessun modello</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="811"/>
      <source>No template available</source>
      <translation>Nessun modello disponibile</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPartSegment</name>
    <message>
      <location filename="../../Command.cpp" line="438"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="439"/>
      <source>Insert part</source>
      <translation>Inserisci parte</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="440"/>
      <source>Insert a new part object into a Raytracing project</source>
      <translation>Inserisce un nuovo oggetto parte in un progetto Raytracing</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPovrayProject</name>
    <message>
      <location filename="../../Command.cpp" line="321"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="322"/>
      <source>New POV-Ray project</source>
      <translation>Nuovo progetto POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="323"/>
      <source>Insert new POV-Ray project into the document</source>
      <translation>Inserisce il nuovo progetto POV-Ray nel documento</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="375"/>
      <source>No template</source>
      <translation>Nessun modello</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="376"/>
      <source>No template available</source>
      <translation>Nessun modello disponibile</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingRender</name>
    <message>
      <location filename="../../Command.cpp" line="589"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="590"/>
      <source>&amp;Render</source>
      <translation>&amp;Render</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="591"/>
      <source>Renders the current raytracing project with an external renderer</source>
      <translation>Esegue il rendering del progetto raytracing corrente con un renderizzatore esterno</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingResetCamera</name>
    <message>
      <location filename="../../Command.cpp" line="869"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="870"/>
      <source>&amp;Reset Camera</source>
      <translation>&amp;Reset Camera</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="871"/>
      <source>Sets the camera of the selected Raytracing project to match the current view</source>
      <translation>Imposta la camera del progetto Raytracing selezionato in modo da farla corrispondere con la visualizzazione corrente</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteCamera</name>
    <message>
      <location filename="../../Command.cpp" line="82"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <source>Export camera to POV-Ray...</source>
      <translation>Esporta la camera in POV-Ray...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <source>Export the camera position of the active 3D view in POV-Ray format to a file</source>
      <translation>Esporta la posizione della telecamera della vista 3D attiva in un file in formato POV-Ray</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWritePart</name>
    <message>
      <location filename="../../Command.cpp" line="175"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="176"/>
      <source>Export part to POV-Ray...</source>
      <translation>Esporta la parte in POV-Ray...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="177"/>
      <source>Write the selected Part (object) as a POV-Ray file</source>
      <translation>Scrive la parte selezionata (oggetto) in un file POV-Ray</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteView</name>
    <message>
      <location filename="../../Command.cpp" line="98"/>
      <location filename="../../Command.cpp" line="237"/>
      <location filename="../../Command.cpp" line="337"/>
      <location filename="../../Command.cpp" line="772"/>
      <source>No perspective camera</source>
      <translation>Nessuna telecamera di prospettiva</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="99"/>
      <location filename="../../Command.cpp" line="238"/>
      <location filename="../../Command.cpp" line="338"/>
      <source>The current view camera is not perspective and thus resulting in a POV-Ray image that may look different than what was expected.
Do you want to continue?</source>
      <translation>La vista della camera corrente non è in prospettiva e quindi l'immagine POV-Ray risultante potrebbe apparire diversa da quella attesa. Si desidera continuare?</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Export view to POV-Ray...</source>
      <translation>Esporta la vista in POV-Ray...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Write the active 3D view with camera and all its content to a POV-Ray file</source>
      <translation>Scrive in un file POV-Ray la vista attiva 3D, con la camera e tutto il suo contenuto</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="352"/>
      <location filename="../../Command.cpp" line="787"/>
      <source>No template</source>
      <translation>Nessun modello</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="353"/>
      <location filename="../../Command.cpp" line="788"/>
      <source>Cannot create a project because there is no template installed.</source>
      <translation>Non è possibile creare un progetto, perché non c'è nessun modello installato.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="773"/>
      <source>The current view camera is not perspective and thus resulting in a luxrender image that may look different than what was expected.
Do you want to continue?</source>
      <translation>La vista della camera corrente non è in prospettiva e quindi l'immagine Pov-Ray risultante potrebbe apparire diversa da quella attesa. Si desidera continuare?</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="186"/>
      <location filename="../../Command.cpp" line="248"/>
      <location filename="../../Command.cpp" line="546"/>
      <source>POV-Ray</source>
      <translation>POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="136"/>
      <location filename="../../Command.cpp" line="187"/>
      <location filename="../../Command.cpp" line="249"/>
      <location filename="../../Command.cpp" line="551"/>
      <location filename="../../Command.cpp" line="665"/>
      <source>All Files</source>
      <translation>Tutti i file</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="137"/>
      <location filename="../../Command.cpp" line="188"/>
      <location filename="../../Command.cpp" line="251"/>
      <location filename="../../Command.cpp" line="553"/>
      <source>Export page</source>
      <translation>Esporta pagina</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="450"/>
      <location filename="../../Command.cpp" line="537"/>
      <location filename="../../Command.cpp" line="605"/>
      <location filename="../../Command.cpp" line="883"/>
      <source>Wrong selection</source>
      <translation>Selezione errata</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="451"/>
      <source>Select a Part object.</source>
      <translation>Selezionare un oggetto Part.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="461"/>
      <location filename="../../Command.cpp" line="473"/>
      <source>No Raytracing project to insert</source>
      <translation>Nessun progetto Raytracing da inserire</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="462"/>
      <source>Create a Raytracing project to insert a view.</source>
      <translation>Crea un progetto Raytracing per inserire una vista.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="474"/>
      <source>Select a Raytracing project to insert the view.</source>
      <translation>Selezionare un progetto Raytracing per inserire la vista.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="538"/>
      <location filename="../../Command.cpp" line="606"/>
      <location filename="../../Command.cpp" line="884"/>
      <source>Select one Raytracing project object.</source>
      <translation>Selezionare un oggetto progetto Raytracing.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="542"/>
      <source>Luxrender</source>
      <translation>LuxRender</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="621"/>
      <location filename="../../Command.cpp" line="627"/>
      <source>POV-Ray not found</source>
      <translation>POV-Ray non trovato</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="622"/>
      <source>Please set the path to the POV-Ray executable in the preferences.</source>
      <translation>Prego impostare il percorso dell'eseguibile di POV-Ray nelle preferenze.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="628"/>
      <source>Please correct the path to the POV-Ray executable in the preferences.</source>
      <translation>Si prega di correggere il percorso dell'eseguibile di POV-Ray nelle preferenze.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="635"/>
      <location filename="../../Command.cpp" line="641"/>
      <source>Luxrender not found</source>
      <translation>LuxRender non trovato</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="636"/>
      <source>Please set the path to the luxrender or luxconsole executable in the preferences.</source>
      <translation>Impostare il percorso dell'eseguibile luxrender o luxconsole nelle preferenze.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="642"/>
      <source>Please correct the path to the luxrender or luxconsole executable in the preferences.</source>
      <translation>Correggere il percorso dell'eseguibile luxrender o luxconsole nelle preferenze.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="654"/>
      <source>POV-Ray file missing</source>
      <translation>Manca il file POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="655"/>
      <source>The POV-Ray project file doesn't exist.</source>
      <translation>Il file del progetto POV-Ray non esiste.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="661"/>
      <location filename="../../Command.cpp" line="663"/>
      <location filename="../../Command.cpp" line="666"/>
      <source>Rendered image</source>
      <translation>Immagine renderizzata</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="723"/>
      <source>Lux project file missing</source>
      <translation>Manca il file del progetto Lux</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="724"/>
      <source>The Lux project file doesn't exist.</source>
      <translation>Il file del progetto Lux non esiste.</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRay</name>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="14"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="26"/>
      <source>Mesh export settings</source>
      <translation>Impostazioni di esportazione mesh</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="52"/>
      <source>Max mesh deviation:</source>
      <translation>Deviazione massima della maglia:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="80"/>
      <source>Do not calculate vertex normals</source>
      <translation>Non calcolare le normali ai vertici</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="93"/>
      <source>Write u,v coordinates</source>
      <translation>Salva le coordinate u,v</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="109"/>
      <source>Render</source>
      <translation>Render</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="127"/>
      <source>POV-Ray executable:</source>
      <translation>Eseguibile di POV-Ray:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="134"/>
      <source>POV-Ray output parameters:</source>
      <translation>Parametri di output di POV-Ray:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="143"/>
      <source>The POV-Ray parameters to be passed to the render.</source>
      <translation>I parametri POV-Ray da passare per il rendering.</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="146"/>
      <source>+P +A</source>
      <translation>+P +A</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="159"/>
      <source>+W: </source>
      <translation>+W: </translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="166"/>
      <source>The width of the rendered image</source>
      <translation>La larghezza dell'immagine renderizzata</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="185"/>
      <source> +H : </source>
      <translation> +H : </translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="192"/>
      <source>The height of the rendered image</source>
      <translation>L'altezza dell'immagine renderizzata</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="213"/>
      <source>Luxrender executable:</source>
      <translation>Eseguibile LuxRender:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="220"/>
      <source>The path to the luxrender (or luxconsole) executable</source>
      <translation>Il percorso dell'eseguibile luxrender (o luxconsole)</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="238"/>
      <source>Directories</source>
      <translation>Cartelle</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="258"/>
      <source>Part file name:</source>
      <translation>Nome del file della parte:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="265"/>
      <source>Camera file name:</source>
      <translation>Nome del file della telecamera:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="275"/>
      <location filename="../../DlgSettingsRay.ui" line="298"/>
      <location filename="../../DlgSettingsRay.ui" line="314"/>
      <source>Used by utility tools</source>
      <translation>Usata dagli strumenti di utilità</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="291"/>
      <source>Default Project dir:</source>
      <translation>Cartella di default del progetto:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="301"/>
      <source>TempCamera.inc</source>
      <translation>TempCamera.inc</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="317"/>
      <source>TempPart.inc</source>
      <translation>TempPart.inc</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRayImp</name>
    <message>
      <location filename="../../DlgSettingsRayImp.cpp" line="47"/>
      <source>The path to the POV-Ray executable, if you want to render from %1</source>
      <translation>Il percorso dell'eseguibile POV-Ray, se si desidera eseguire il rendering da %1</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::ViewProviderLux</name>
    <message>
      <location filename="../../ViewProvider.cpp" line="68"/>
      <source>Edit LuxRender project</source>
      <translation>Modifica progetto LuxRender</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="99"/>
      <source>LuxRender template</source>
      <translation>Modello LuxRender</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="99"/>
      <source>Select a LuxRender template</source>
      <translation>Selezionare un modello LuxRender</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::ViewProviderPovray</name>
    <message>
      <location filename="../../ViewProvider.cpp" line="147"/>
      <source>Edit Povray project</source>
      <translation>Modifica progetto Povray</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="178"/>
      <source>Povray template</source>
      <translation>Modello Povray</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="178"/>
      <source>Select a Povray template</source>
      <translation>Selezionare un modello Povray</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Raytracing</translation>
    </message>
  </context>
</TS>
